@@ -615,10 +615,14 @@ _base_flags.update({
 })
 _base_flags['python'] = _base_flags['py']
 
+_base_aliases = {}
+_base_aliases.update(JupyterApp.aliases)
+
 class BaseNBExtensionApp(JupyterApp):
     """Base nbextension installer app"""
     _log_formatter_cls = LogFormatter
     flags = _base_flags
+    aliases = _base_aliases
     version = __version__
     
     user = Bool(False, config=True, help="Whether to do a user install")
@@ -655,11 +659,13 @@ flags.update({
 
 flags['s'] = flags['symlink']
 
-aliases = {
+aliases = {}
+aliases.update(_base_aliases)
+aliases.update({
     "prefix" : "InstallNBExtensionApp.prefix",
     "nbextensions" : "InstallNBExtensionApp.nbextensions_dir",
     "destination" : "InstallNBExtensionApp.destination",
-}
+})
 
 class InstallNBExtensionApp(BaseNBExtensionApp):
     """Entry point for installing notebook extensions"""
@@ -686,7 +692,8 @@ class InstallNBExtensionApp(BaseNBExtensionApp):
     symlink = Bool(False, config=True, help="Create symlinks instead of copying files")
 
     prefix = Unicode('', config=True, help="Installation prefix")
-    nbextensions_dir = Unicode('', config=True, help="Full path to nbextensions dir (probably use prefix or user)")
+    nbextensions_dir = Unicode('', config=True,
+           help="Full path to nbextensions dir (probably use prefix or user)")
     destination = Unicode('', config=True, help="Destination for the copy or symlink")
 
     def _config_file_name_default(self):
@@ -696,9 +703,15 @@ class InstallNBExtensionApp(BaseNBExtensionApp):
     def install_extensions(self):
         """Perform the installation of nbextension(s)"""
         if len(self.extra_args)>1:
-            raise ValueError("only one nbextension allowed at a time.  Call multiple times to install multiple extensions.")
-        
-        install = install_nbextension_python if self.python else install_nbextension
+            raise ValueError("Only one nbextension allowed at a time. "
+                         "Call multiple times to install multiple extensions.")
+
+        if self.python:
+            install = install_nbextension_python
+            kwargs = {}
+        else:
+            install = install_nbextension
+            kwargs = {'destination': self.destination}
         
         full_dests = install(self.extra_args[0],
                              overwrite=self.overwrite,
@@ -707,7 +720,9 @@ class InstallNBExtensionApp(BaseNBExtensionApp):
                              sys_prefix=self.sys_prefix,
                              prefix=self.prefix,
                              nbextensions_dir=self.nbextensions_dir,
-                             logger=self.log)
+                             logger=self.log,
+                             **kwargs
+                            )
 
         if full_dests:
             self.log.info(
@@ -755,6 +770,7 @@ class UninstallNBExtensionApp(BaseNBExtensionApp):
         "nbextensions" : "UninstallNBExtensionApp.nbextensions_dir",
         "require": "UninstallNBExtensionApp.require",
     }
+    aliases.update(_base_aliases)
     
     prefix = Unicode('', config=True, help="Installation prefix")
     nbextensions_dir = Unicode('', config=True, help="Full path to nbextensions dir (probably use prefix or user)")
@@ -809,6 +825,7 @@ class ToggleNBExtensionApp(BaseNBExtensionApp):
     user = Bool(True, config=True, help="Apply the configuration only for the current user (default)")
 
     aliases = {'section': 'ToggleNBExtensionApp.section'}
+    aliases.update(_base_aliases)
     
     _toggle_value = None
 
@@ -1042,8 +1059,17 @@ def _get_nbextension_dir(user=False, sys_prefix=False, prefix=None, nbextensions
     nbextensions_dir : str [optional]
         Get what you put in
     """
-    if sum(map(bool, [user, prefix, nbextensions_dir, sys_prefix])) > 1:
-        raise ArgumentConflict("cannot specify more than one of user, sys_prefix, prefix, or nbextensions_dir")
+    conflicting = [
+        ('user', user),
+        ('prefix', prefix),
+        ('nbextensions_dir', nbextensions_dir),
+        ('sys_prefix', sys_prefix),
+    ]
+    conflicting_set = ['{}={!r}'.format(n, v) for n, v in conflicting if v]
+    if len(conflicting_set) > 1:
+        raise ArgumentConflict(
+            "cannot specify more than one of user, sys_prefix, prefix, or nbextensions_dir, but got: {}"
+            .format(', '.join(conflicting_set)))
     if user:
         nbext = pjoin(jupyter_data_dir(), u'nbextensions')
     elif sys_prefix:
@@ -1113,7 +1139,8 @@ def _get_nbextension_metadata(module):
     """
     m = import_item(module)
     if not hasattr(m, '_jupyter_nbextension_paths'):
-        raise KeyError('The Python module {} is not a valid nbextension'.format(module))
+        raise KeyError('The Python module {} is not a valid nbextension, '
+                       'it is missing the `_jupyter_nbextension_paths()` method.'.format(module))
     nbexts = m._jupyter_nbextension_paths()
     return m, nbexts
 
